*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table 2: Contemporary Household Outcomes: Dynamics Across Years
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the ado-file that implements the Conley Standard Errors (ols_spatial_HAC)
global dirado "..."

*Path to the final outputs (tables)
global dirout "..."

*Load the program that implements the Conley Standard Errors (ols_spatial_HAC)
run "$dirado/ols_spatial_HAC.ado" 

*Load dataset
use "$dirdata/Astua_Pirie_HH.dta", clear

*Initialize the group of variables:

*Geographic controls
local geographic elevation slope average_temp

*Demographic controls
local hh_controls adult infant children

*Census Fixed Effects
local year_fe y_2000 y_2011 y_1984 y_1973

*Latitude and longitude
local coordinates lat lon 

*Outcome variables
foreach outcome in housing health education consumption poor ubn   {

display "`outcome'"

*********************************************************************************************************************************************************************************************************************************************
* Table 2: Contemporary Household Outcomes: Dynamics Across Years
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, vce(cluster census_block)
	
	*Store results
	estimates store m_`outcome'
	
	*Mean of the dependent variable for each year
	foreach j in 1973 1984 2000 2011 {	
	sum `outcome' if distance<5 & year==`j'
	scalar r_mean_`j' = r(mean)
	estadd scalar r_mean_`j': m_`outcome'
	}

*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store results (Conley Standard Errors)
	scalar se_conley_1973 = _se[UFCo_1973]
	scalar se_conley_1984 = _se[UFCo_1984]
	scalar se_conley_2000 = _se[UFCo_2000]
	scalar se_conley_2011 = _se[UFCo_2011]		
	
	foreach j in 1973 1984 2000 2011 {	
	local t = _b[UFCo_`j']/_se[UFCo_`j']
	local p =2*ttail(e(df_r),abs(`t'))
	if `j' == 1973 {
	matrix r_se_`j' = (`=se_conley_`j'', ., ., ., ., ., ., ., ., ., ., ., ., ., ., ., .)
	matrix r_p_`j' = (`p', ., ., ., ., ., ., ., ., ., ., ., ., ., ., ., .)	
	}
	if `j' == 1984 {
	matrix r_se_`j' = (., `=se_conley_`j'', ., ., ., ., ., ., ., ., ., ., ., ., ., ., .)
	matrix r_p_`j' = (., `p', ., ., ., ., ., ., ., ., ., ., ., ., ., ., .)	
	}	
	if `j' == 2000 {
	matrix r_se_`j' = (., ., `=se_conley_`j'', ., ., ., ., ., ., ., ., ., ., ., ., ., .)
	matrix r_p_`j' = (., ., `p', ., ., ., ., ., ., ., ., ., ., ., ., ., .)	
	}
	if `j' == 2011 {
	matrix r_se_`j' = (., ., ., `=se_conley_`j'', ., ., ., ., ., ., ., ., ., ., ., ., .)
	matrix r_p_`j' = (., ., ., `p', ., ., ., ., ., ., ., ., ., ., ., ., .)	
	}	
	mat colnames r_se_`j' = UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 . . . . . . . . . . . . .
	mat colnames r_p_`j' = UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 . . . . . . . . . . . . .	
	estadd matrix r_se_`j': m_`outcome'
	estadd matrix r_p_`j': m_`outcome'
	}
	
}

*Generate Table 2 using previous results
esttab m_housing m_health m_education m_consumption m_poor m_ubn using "$dirout/Table_2.tex", cells(b(fmt(3)) se(par fmt(3) star) ///
r_se_1973(par([ ]) fmt(3) star pvalue(r_p_1973)) r_se_1984(par([ ]) fmt(3) star pvalue(r_p_1984)) r_se_2000(par([ ]) fmt(3) star pvalue(r_p_2000)) ///
r_se_2011(par([ ]) fmt(3) star pvalue(r_p_2011))) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2_a N N_clust r_mean_1973 r_mean_1984 r_mean_2000 r_mean_2011, fmt(3 0 0 3 3 3 3) label("Adjusted \(R^{2}\)" "Observations" "Clusters" "Mean$_{1973}$" "Mean$_{1984}$" "Mean$_{2000}$" "Mean$_{2011}$")) ///
keep(UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011) ///
collabels(none) ///
mlabels("Housing" "Health" "Education" "Consumption" "Probability of being poor" "Total number of UBN") ///
title("Table 2: Contemporary Household Outcomes: Dynamics Across Years") ///
addnotes("\scriptsize \textit{Notes:} UBN= Unsatisfied Basic Need. The unit of observation is the household. Robust standard errors, adjusted for clustering by census block, are in parentheses. Conley standard errors are in brackets. All regressions include geographic controls (slope, elevation, temperature); demographic controls for the number of adults, children, and infants in the household; census fixed effects, and a linear polynomial in latitude and longitude. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).") ///
replace