*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table 4: IV Strategy: Outside Options in 1973 for UFCo Workers and Outcomes in 2000 and 2011 within the UFCo
*Due to the sample size, it is preferable to estimate the Conley Standard Errors in MATLAB (code: Table_4_Conley_Standard_Errors.m) 
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the final outputs (tables)
global dirout "..."

*********************************************************************************************************************************************************************************************************************************************
* Table 4: IV Strategy: Outside Options in 1973 for UFCo Workers and Outcomes in 2000 and 2011 within the UFCo
*********************************************************************************************************************************************************************************************************************************************
********************************* First Stage *********************************
*Load dataset
use "$dirdata/wages_coffee_intensity_dataset.dta", clear

*Estimate the relationship between wages and coffee intensity
ivregress 2sls lw age agesqrt female yrs_sch (coffee_int  = slope_dist average_temp_dist elevation_dist lat_dist lon_dist ), cluster( ID_DISTRITO )

estimates store m_1
	
*Obtain various statistics measuring the relevance of instrumental variable
estat firststage

scalar r_adj = r(singleresults)[1,2] //Adjusted R2
estadd scalar r_adj: m_1

scalar r_f = r(singleresults)[1,4] //Adjusted R2
estadd scalar r_f: m_1

*Generate Table 4 - First Stage
esttab m_1 using "$dirout/Table_4_first_stage.tex", cells(b(fmt(3)) se(par fmt(3) star)) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(N N_clust r_f r_adj, fmt(0 0 3 3) label("Observations" "Clusters" "F-Statistic" "Adjusted \(R^{2}\)")) ///
keep(coffee_int) ///
varlabels(coffee_int "ln Distance-Weighted Coffee Intensity") ///
collabels(none) ///
mlabels("First stage") ///
title("Table 4: IV Strategy: Outside Options in 1973 for UFCo Workers and Outcomes in 2000 and 2011 within the UFCo") ///
addnotes("\scriptsize \textit{Notes:} First stage: coffee intensity and wages are measured at district level. Second stage: UBN = Unsatisfied Basic Need. The unit of observation is the individual.  Robust standard errors, adjusted for clustering by district-year, are in parentheses. All regressions (both stages) include controls for contemporaneous outside options; the number of adults, children, and infants in the household; census fixed effects, and a linear polynomial in latitude and longitude. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).") ///
replace

eststo clear

********************************* Second Stage *********************************
*Load dataset
use "$dirdata/outside_option_dataset.dta", clear

*Initialize the group of variables:

*Demographic controls
local hh_controls adult infant children

*Census Fixed Effects
local year_fe y_2000 y_2011

*Latitude and longitude
local coordinates lat_dist lon_dist 

foreach outcome in housing health education consumption poor ubn {
	
display "`outcome'"	
		
*List of covariates
local covariates `coordinates' `hh_controls' `year_fe' log_outside_option_current

	reg `outcome' log_outside_option_1973 `covariates', vce(cluster district)

	*Store results
	estimates store m_`outcome'
	
	*Mean of the dependent variable and variation with respect to mean
	sum `outcome' if e(sample)==1 //Mean dependent variable
	scalar r_mean = r(mean)
	estadd scalar r_mean: m_`outcome'	
	
*Generate file to estimate Conley Standard Errors in MATLAB
	outsheet `outcome' log_outside_option_1973 `covariates' district using "$dirout/`outcome'_outside_option.csv", comma nolabel replace	

}

*Generate Table 4 - Second Stage (except for Conley Standard Errors)
esttab m_housing m_health m_education m_consumption m_poor m_ubn using "$dirout/Table_4_second_stage.tex", cells(b(fmt(3)) se(par fmt(3) star)) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2_a N N_clust r_mean, fmt(3 0 0 3) label("Adjusted \(R^{2}\)" "Observations" "Clusters" "Mean")) ///
keep(log_outside_option_1973) ///
varlabels(log_outside_option_1973 "ln Outside Option in 1973") ///
collabels(none) ///
mlabels("Housing" "Health" "Education" "Consumption" "Probability of being poor" "Total number of UBN") ///
title("Table 4: IV Strategy: Outside Options in 1973 for UFCo Workers and Outcomes in 2000 and 2011 within the UFCo") ///
addnotes("\scriptsize \textit{Notes:} First stage: coffee intensity and wages are measured at district level. Second stage: UBN = Unsatisfied Basic Need. The unit of observation is the individual.  Robust standard errors, adjusted for clustering by district-year, are in parentheses. All regressions (both stages) include controls for contemporaneous outside options; the number of adults, children, and infants in the household; census fixed effects, and a linear polynomial in latitude and longitude. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).") ///
replace