*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table D.4: Average UFCo Effect Along All Border Segments where Characteristics Balance
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the ado-file that implements the Conley Standard Errors (ols_spatial_HAC)
global dirado "..."

*Path to the final outputs (tables)
global dirout "..."

*Load the program that implements the Conley Standard Errors (ols_spatial_HAC)
run "$dirado/ols_spatial_HAC.ado" 

*Load dataset
use "$dirdata/all_charact_balance_HH.dta", replace

*Initialize the group of variables:

*Geographic controls
local geographic elevation slope average_temp

*Demographic controls
local hh_controls adult infant children

*Census Fixed Effects
local year_fe y_2000 y_2011 y_1984 y_1973

*Latitude and longitude
local coordinates lat lon 

*Outcome variables
foreach outcome in housing health education consumption poor ubn {
	
display "`outcome'"	

*********************************************************************************************************************************************************************************************************************************************
* Table D.4: Average UFCo Effect Along All Border Segments where Characteristics Balance
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<4, vce(cluster census_block)

	*Store results
	estimates store m_`outcome'
	
	*Mean of the dependent variable and variation with respect to mean
	sum `outcome' if distance<4 //Mean dependent variable
	scalar r_mean = r(mean)
	estadd scalar r_mean: m_`outcome'	
	
	scalar var_mean = _b[UFCo]/r(mean)*100 // % Variation with respect to mean
	estadd scalar var_mean: m_`outcome'

*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<4, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store results (Conley Standard Errors)
	scalar se_conley = _se[UFCo]

	local t = _b[UFCo]/_se[UFCo]
	local p =2*ttail(e(df_r),abs(`t'))

	matrix r_se = (`=se_conley', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames r_se = UFCo . . . . . . . . . . . . .
	matrix r_p = (`p', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames r_p = UFCo . . . . . . . . . . . . .	
	
	estadd matrix r_se: m_`outcome'
	estadd matrix r_p: m_`outcome'
	
}

*Generate Table D.4 using previous results
esttab m_housing m_health m_education m_consumption m_poor m_ubn using "$dirout/Table_D4.tex", cells(b(fmt(3)) se(par fmt(3) star) r_se(par([ ]) fmt(3) star pvalue(r_p)) ) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2_a N N_clust r_mean, fmt(3 0 0 3) label("Adjusted \(R^{2}\)" "Observations" "Clusters" "Mean")) ///
keep(UFCo) ///
collabels(none) ///
mlabels("Housing" "Health" "Education" "Consumption" "Probability of being poor" "Total number of UBN") ///
title("Table D.4: Average UFCo Effect Along All Border Segments where Characteristics Balance") ///
addnotes("\scriptsize \textit{Notes:} UBN=Unsatisfied Basic Need. The last row shows the percentage variation in each coefficient with respect to the sample's mean. The unit of observation is the household. Robust standard errors, adjusted for clustering by census block, are in parentheses. Conley standard errors are in brackets. All regressions include geographic controls (slope, elevation, temperature); demographic controls for the number of adults, children, and infants in the household; census fixed effects, and a linear polynomial in latitude and longitude. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\). \par") ///
replace