*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table F.6: Average UFCo Effect: Placebo Tests 2 km and 4 km
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the ado-file that implements the Conley Standard Errors (ols_spatial_HAC)
global dirado "..."

*Path to the final outputs (tables)
global dirout "..."

*Load the program that implements the Conley Standard Errors (ols_spatial_HAC)
run "$dirado/ols_spatial_HAC.ado" 

*Load dataset
use "$dirdata/Astua_Pirie_HH.dta", clear

*Initialize the group of variables:

*Geographic controls
local geographic elevation slope average_temp

*Demographic controls
local hh_controls adult infant children

*Census Fixed Effects
local year_fe y_2000 y_2011 y_1984 y_1973

*Latitude and longitude
local coordinates lat lon 

*Outcome variables
foreach placebo in UFCo_f2p UFCo_f2m UFCo_f4p UFCo_f4m {
	
display "`placebo'"	
	
* UFCo_f2p : Placebo at +2 km
* UFCo_f2m : Placebo at -2 km
* UFCo_f4p : Placebo at +4 km
* UFCo_f4m : Placebo at -4 km

if "`placebo'" == "UFCo_f2p" {
	local explanation "Placebo at +2 km"
}
if "`placebo'" == "UFCo_f2m" {
	local explanation "Placebo at -2 km"
}
if "`placebo'" == "UFCo_f4p" {
	local explanation "Placebo at +4 km"
}
if "`placebo'" == "UFCo_f4m" {
	local explanation "Placebo at -4 km"
}
	
*********************************************************************************************************************************************************************************************************************************************
* Table F.6: Average UFCo Effect: Placebo Tests 2 km and 4 km
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

foreach outcome in housing health education consumption poor ubn {

display "`outcome'"

preserve

*Using Clustered Standard Errors at the Census Block Level	
	reg `outcome' `placebo' `covariates' if distance<5, vce(cluster census_block)

	*Store results
	estimates store m_`outcome'
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' `placebo' `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store results (Conley Standard Errors)
	scalar se_conley = _se[UFCo]

	local t = _b[UFCo]/_se[UFCo]
	local p =2*ttail(e(df_r),abs(`t'))

	matrix r_se = (`=se_conley', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames r_se = `placebo' . . . . . . . . . . . . .
	matrix r_p = (`p', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames r_p = `placebo' . . . . . . . . . . . . .	
	
	estadd matrix r_se: m_`outcome'
	estadd matrix r_p: m_`outcome'	

restore
	
}

*Generate Table F.6 using previous results
esttab m_housing m_health m_education m_consumption m_poor m_ubn using "$dirout/Table_F6_`placebo'.tex", cells(b(fmt(3)) se(par fmt(3) star) r_se(par([ ]) fmt(3) star pvalue(r_p)) ) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2_a N N_clust, fmt(3 0 0) label("Adjusted \(R^{2}\)" "Observations" "Clusters")) ///
keep(`placebo') ///
collabels(none) ///
mlabels("Housing" "Health" "Education" "Consumption" "Probability of being poor" "Total number of UBN") ///
title("Table F.6: Average UFCo Effect: `explanation'") ///
addnotes("\scriptsize \textit{Notes:} All regressions include 9,179 observations and 206 clusters. +2 km and +4 km refer to shifting the  boundary 2 km and 4 km North, respectively; while -2 km and -4 km refer to shifting the  boundary 2 km and 4 km South.  UBN= Unsatisfied Basic Need. The unit of observation is the household. Robust standard errors, adjusted for clustering by census block, are in parentheses. Conley standard errors are in brackets. All regressions include geographic controls (slope, elevation, temperature); demographic controls for the number of adults, children, and infants in the household; census fixed effects, and a linear polynomial in latitude and longitude.  We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).") ///
replace
	
}	