*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table I.12: Human Capital: Control Region Outside UFCo vs. Other Non-UFCo Rural Regions
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the ado-file that implements the Conley Standard Errors (ols_spatial_HAC)
*and the Imbens-Kolesar Standard Errors (SE_IK and CR23_IK_CSS)
global dirado "..."

*Path to the final outputs (tables)
global dirout "..."

*Load the program that implements the Conley Standard Errors (ols_spatial_HAC)
*and the Imbens-Kolesar Standard Errors (SE_IK and CR23_IK_CSS)
run "$dirado/ols_spatial_HAC.ado" 
run "$dirado/SE_IK.do" 
run "$dirado/CR23_IK_CSS.do" 

*Load dataset
use "$dirdata/human_capital_comparison.dta", replace

*Initialize the group of variables:

*Geographic controls
local geographic elevation slope average_temp

*Demographic controls
local ind_controls age agesqrt female

*Latitude and longitude
local coordinates lat lon 

*Outcome variables
foreach outcome in yrs_sch primary secondary {
	
display "`outcome'"	

*********************************************************************************************************************************************************************************************************************************************
* Table I.12: Human Capital: Control Region Outside UFCo vs. Other Non-UFCo Rural Regions - Migrants
*********************************************************************************************************************************************************************************************************************************************
preserve

drop if migration == 0 //Keep only migrants

*List of covariates
local covariates `coordinates' `geographic' `ind_controls'

*Using Imbens-Kolesar Standard Errors
	reg `outcome' control_region `covariates', vce(cluster census_block)

	estimate_the_SE_IK, outcome(`outcome') covariates(`covariates') distance(.)
	
	local se_IK =  e(se_CR2) 
	local p = e(p_CR2_Tik)
	
	*Store results
	estimates store m_`outcome'
	
	matrix se_IK = (`se_IK', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames se_IK = control_region . . . . . . . . . . . . .
	matrix se_IK_p = (`p', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames se_IK_p = control_region . . . . . . . . . . . . .	
	
	estadd matrix se_IK: m_`outcome'
	estadd matrix se_IK_p: m_`outcome'	
	
	*Mean of the dependent variable
	sum `outcome'
	scalar r_mean = r(mean)
	estadd scalar r_mean: m_`outcome'
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' control_region cons `covariates', lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)

	*Store results (Conley Standard Errors)
	scalar se_conley = _se[control_region]

	local t = _b[control_region]/_se[control_region]
	local p =2*ttail(e(df_r),abs(`t'))

	matrix se_conley = (`=se_conley', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames se_conley = control_region . . . . . . . . . . . . .
	matrix se_conley_p = (`p', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames se_conley_p = control_region . . . . . . . . . . . . .	
	
	estadd matrix se_conley: m_`outcome'
	estadd matrix se_conley_p: m_`outcome'	

restore
}

*Generate Table I.12 - Migrants
esttab m_yrs_sch m_primary m_secondary using "$dirout/Table_I12_Migrants.tex", cells(b(fmt(3)) se_IK(par fmt(3) star pvalue(se_IK_p)) se_conley(par([ ]) fmt(3) star pvalue(se_conley_p)) ) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2_a N N_clust r_mean, fmt(3 0 0 3) label("Adjusted \(R^{2}\)" "Observations" "Clusters" "Mean")) ///
keep(control_region) ///
collabels(none) ///
mlabels("Years of schooling" "Primary" "Secondary") ///
title("Table I.12: Human Capital: Control Region Outside UFCo vs. Other Non-UFCo Rural Regions - Migrants") ///
addnotes("\scriptsize \textit{Notes:} The unit of observation is the individual. Robust standard errors clustered by census block, are in parentheses. Due to number of unbalanced clusters, we follow \citeSM{Practitioner-Cluster} using the bias-adjusted cluster-robust standard errors, and the data determined degrees of freedom adjustment in \citeSM{Imbens_Kolesar}.  Conley standard errors in brackets. All regressions include geographic and individual controls, and a linear polynomial in latitude and longitude. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).") ///
replace

*Outcome variables
foreach outcome in yrs_sch primary secondary {
	
display "`outcome'"	

*********************************************************************************************************************************************************************************************************************************************
* Table I.12: Human Capital: Control Region Outside UFCo vs. Other Non-UFCo Rural Regions - All Population
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `geographic' `ind_controls'

*Using Imbens-Kolesar Standard Errors
	reg `outcome' control_region `covariates', vce(cluster census_block)

	estimate_the_SE_IK, outcome(`outcome') covariates(`covariates') distance(.)
	
	local se_IK =  e(se_CR2) 
	local p = e(p_CR2_Tik)
	
	*Store results
	estimates store m_`outcome'
	
	matrix se_IK = (`se_IK', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames se_IK = control_region . . . . . . . . . . . . .
	matrix se_IK_p = (`p', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames se_IK_p = control_region . . . . . . . . . . . . .	
	
	estadd matrix se_IK: m_`outcome'
	estadd matrix se_IK_p: m_`outcome'	
	
	*Mean of the dependent variable
	sum `outcome'
	scalar r_mean = r(mean)
	estadd scalar r_mean: m_`outcome'
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' control_region cons `covariates', lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)

	*Store results (Conley Standard Errors)
	scalar se_conley = _se[control_region]

	local t = _b[control_region]/_se[control_region]
	local p =2*ttail(e(df_r),abs(`t'))

	matrix se_conley = (`=se_conley', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames se_conley = control_region . . . . . . . . . . . . .
	matrix se_conley_p = (`p', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames se_conley_p = control_region . . . . . . . . . . . . .	
	
	estadd matrix se_conley: m_`outcome'
	estadd matrix se_conley_p: m_`outcome'	
	
}

*Generate Table I.12 - All Population
esttab m_yrs_sch m_primary m_secondary using "$dirout/Table_I12_All_Population.tex", cells(b(fmt(3)) se_IK(par fmt(3) star pvalue(se_IK_p)) se_conley(par([ ]) fmt(3) star pvalue(se_conley_p)) ) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2_a N N_clust r_mean, fmt(3 0 0 3) label("Adjusted \(R^{2}\)" "Observations" "Clusters" "Mean")) ///
keep(control_region) ///
collabels(none) ///
mlabels("Years of schooling" "Primary" "Secondary") ///
title("Table I.12: Human Capital: Control Region Outside UFCo vs. Other Non-UFCo Rural Regions - All Population") ///
addnotes("\scriptsize \textit{Notes:} The unit of observation is the individual. Robust standard errors clustered by census block, are in parentheses. Due to number of unbalanced clusters, we follow \citeSM{Practitioner-Cluster} using the bias-adjusted cluster-robust standard errors, and the data determined degrees of freedom adjustment in \citeSM{Imbens_Kolesar}.  Conley standard errors in brackets. All regressions include geographic and individual controls, and a linear polynomial in latitude and longitude. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).") ///
replace	