*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Figure 5: Robustness checks for the Main Specification: Average UFCo Effect
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the ado-file that implements the Conley Standard Errors (ols_spatial_HAC)
global dirado "..."

*Path to the final outputs (figures)
global dirout "..."

*Load the program that implements the Conley Standard Errors (ols_spatial_HAC)
run "$dirado/ols_spatial_HAC.ado" 

*Load dataset
use "$dirdata/Astua_Pirie_HH.dta", clear

*Initialize the group of variables:

*Geographic controls
local geographic elevation slope average_temp

*Demographic controls
local hh_controls adult infant children

*Census Fixed Effects
local year_fe y_2000 y_2011 y_1984 y_1973

*Latitude and longitude
local coordinates lat lon 

*Outcome variables
foreach outcome in housing health education consumption poor ubn {
	
display "`outcome'"	

*Generate the file to save the coefficients
	tempname `outcome' 
	postfile `outcome' beta se se_conley df_r ///
	main ///
	geographic demographic distance_border ///
	distance_rail linear quadratic ///
	river top_10 top_5 ///
	any_mig head_mig ///
	hh_agri hh_no_agri ///
	head_agri head_no_agri ///
	MT_index ///
	using "$dirout/`outcome'.dta", replace
	
*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - Linear polynomial in latitude and longitude
*********************************************************************************************************************************************************************************************************************************************	

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)

	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)

*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]

	*Store coefficients 
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (1) (1) (1) (.) (.) (1) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.)
	
*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - Quadratic polynomial in latitude and longitude
*********************************************************************************************************************************************************************************************************************************************

*For quadratic polynomial, include latsqrt lonsqrt lat_lon in addition to lat and lon as covariates
*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe' latsqrt lonsqrt lat_lon 

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)

	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)

	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]
	
	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (.) (.) (.) (1) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.)	

*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - Linear polynomial in latitude, longitude and distance to the border
*********************************************************************************************************************************************************************************************************************************************

*Include distance to the border as an additional covariate
*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe' distance

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)

	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)	
	scalar se_conley = _se[UFCo]

	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (1) (.) (1) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.)		
	
*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - No demographic controls
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `geographic' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)

*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)

	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]
	
	*Store coefficients 
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (.) (.) (.) (1) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.)
	
*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - No geographic controls
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)

	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]
	
	*Store coefficients 
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (.) (1) (.) (.) (1) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.)
	
*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - No demographic or geographic controls
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)

	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]
	
	*Store coefficients 
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (.) (.) (.) (.) (1) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.)
	
*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - Distance to Railroad
*********************************************************************************************************************************************************************************************************************************************

*Include distance to the railroad as an additional covariate
*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe' dist_railr

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)

	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]
	
	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (.) (1) (1) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.)
	
*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - Méndez & Trejos Index
*********************************************************************************************************************************************************************************************************************************************
preserve

*Keep only 2011 and 2000 Census
keep if inlist(year, 2000, 2011)

local year_fe y_2000 y_2011

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome'_mt UFCo `covariates' if distance<5, vce(cluster census_block)

	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome'_mt UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]
	
	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (.) (.) (1) (.) (.) (.) (.) (.) (.) (.) (.) (.) (.) (1)		

restore

local year_fe y_2000 y_2011 y_1984 y_1973

*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - River
*********************************************************************************************************************************************************************************************************************************************

*Using Clustered Standard Errors at the Census Block Level
local covariates `coordinates' `geographic' `hh_controls' `year_fe'
	
	reg `outcome' UFCo `covariates' if distance<1, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<1, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]
	
	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (.) (.) (1) (.) (1) (.) (.) (.) (.) (.) (.) (.) (.) (.)

*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - Omitting the Top 5% and 10% closest to the border
*********************************************************************************************************************************************************************************************************************************************
preserve

*Before estimating the percentiles, drop observations above threshold
drop if distance>5

*Generate percentile for UFCo region
xtile pctile = distance if UFCo==1, nq(100)

*Generate percentile for non-UFCo region
xtile pctile_non_UFCo = distance if UFCo==0, nq(100)

*Generate a unique percentile variable
replace pctile=pctile_non_UFCo if pctile==.

*Drop 5% closest observations to the border 
drop if pctile<=5

*Using Clustered Standard Errors at the Census Block Level
local covariates `coordinates' `geographic' `hh_controls' `year_fe'
	
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)

	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]
	
	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (.) (.) (1) (.) (.) (1) (.) (.) (.) (.) (.) (.) (.) (.)	
	
*Drop 10% closest observations to the border 
drop if pctile<=10

*Using Clustered Standard Errors at the Census Block Level
local covariates `coordinates' `geographic' `hh_controls' `year_fe'
	
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]
	
	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (.) (.) (1) (.) (.) (.) (1) (.) (.) (.) (.) (.) (.) (.)		
	
restore			

*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - All members non-migrants
*********************************************************************************************************************************************************************************************************************************************
preserve

*Drop household if any member is migrant
drop if migration==1

*List of covariates 
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)

*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]
	
	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (.) (.) (1) (.) (.) (.) (.) (1) (.) (.) (.) (.) (.) (.)
	
restore

*Compare coefficients with main specification (Table 3)
reg `outcome' UFCo `covariates' if distance<5
estimates store m1

reg `outcome' UFCo `covariates' if distance<5 & migration==0
estimates store m2

suest m1 m2, vce(cluster census_block)

test [m1_mean]UFCo-[m2_mean]UFCo = 0

*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - Head of household non-migrant
*********************************************************************************************************************************************************************************************************************************************
preserve

*Drop household if head of household is migrant
drop if migration_head==1

*List of covariates  
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]
	
	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (.) (.) (1) (.) (.) (.) (.) (.) (1) (.) (.) (.) (.) (.)	

restore

*Compare coefficients with main specification (Table 3)
reg `outcome' UFCo `covariates' if distance<5
estimates store m1

reg `outcome' UFCo `covariates' if distance<5 & migration_head==0
estimates store m2

suest m1 m2, vce(cluster census_block)

test [m1_mean]UFCo-[m2_mean]UFCo = 0	

*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - At least one member in agriculture
*********************************************************************************************************************************************************************************************************************************************
preserve

*Keep households with any member working in the agriculture sector
drop if agri_ind==0

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)

	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]

	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (.) (.) (1) (.) (.) (.) (.) (.) (.) (1) (.) (.) (.) (.)	
		
restore

*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - No members in agriculture
*********************************************************************************************************************************************************************************************************************************************
preserve

*Drop households with any member working in the agriculture sector
drop if agri_ind==1

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)

	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]

	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (.) (.) (1) (.) (.) (.) (.) (.) (.) (.) (1) (.) (.) (.)	
	
restore

*Compare coefficients between sectors 
reg `outcome' UFCo `covariates' if distance<5 & agri_ind==1
estimates store m1

reg `outcome' UFCo `covariates' if distance<5 & agri_ind==0
estimates store m2

suest m1 m2, vce(cluster census_block)

test [m1_mean]UFCo-[m2_mean]UFCo = 0

*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - Head of household in agriculture
*********************************************************************************************************************************************************************************************************************************************
preserve

*Keep households with head of household working in the agriculture sector
drop if agri_head==0

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)

	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]

	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (.) (.) (1) (.) (.) (.) (.) (.) (.) (.) (.) (1) (.) (.)	
		
restore

*********************************************************************************************************************************************************************************************************************************************
* Figure 5 - Head of household not in agriculture
*********************************************************************************************************************************************************************************************************************************************
preserve

*Drop households with head of household working in the agriculture sector
drop if agri_head==1

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef = _b[UFCo]
	scalar se = _se[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley = _se[UFCo]

	*Store coefficients 	
	post `outcome' (`=coef') (`=se') (`=se_conley') (`=df_r') (.) (1) (1) (.) (.) (1) (.) (.) (.) (.) (.) (.) (.) (.) (.) (1) (.)	
	
restore

*Compare coefficients between sectors
reg `outcome' UFCo `covariates' if distance<5 & agri_head==1
estimates store m1

reg `outcome' UFCo `covariates' if distance<5 & agri_head==0
estimates store m2

suest m1 m2, vce(cluster census_block)

test [m1_mean]UFCo-[m2_mean]UFCo = 0

*********************************************************************************************************************************************************************************************************************************************
* Close file that saves coefficients and standard errors
*********************************************************************************************************************************************************************************************************************************************
postclose `outcome'
}	

*********************************************************************************************************************************************************************************************************************************************
* Generate summary figure
*********************************************************************************************************************************************************************************************************************************************
*Based on the specification curve code ("speccurve") by Hans H. Sievertsen. Available at: https://github.com/hhsievertsen/speccurve
foreach outcome in housing health education consumption poor ubn   {
display "`outcome'"
use "$dirout/`outcome'.dta",clear

*Specification id
gen spec_id = _n

*Confidence intervals
gen u95=beta+invt(df_r,0.975)*se
gen l95=beta-invt(df_r,0.975)*se

gen u95_conley=beta+invt(df_r,0.975)*se_conley
gen l95_conley=beta-invt(df_r,0.975)*se_conley

if "`outcome'"=="housing" local vtext_range "0(-0.10)-0.20"
if "`outcome'"=="housing" local vtextA "-0.26"
if "`outcome'"=="housing" local pos "30 35"
if "`outcome'"=="housing" local vlabel "Housing"
if "`outcome'"=="housing" local vlabelfile "Housing"

if "`outcome'"=="health" local vtext_range "0(-0.05)-0.10"
if "`outcome'"=="health" local vtextA "-0.16"
if "`outcome'"=="health" local pos "29 35"
if "`outcome'"=="health" local vlabel "Health"
if "`outcome'"=="health" local vlabelfile "Health"

if "`outcome'"=="education" local vtext_range "0(-0.05)-0.15"
if "`outcome'"=="education" local vtextA "-0.21"
if "`outcome'"=="education" local pos "29 35"
if "`outcome'"=="education" local vlabel "Education"
if "`outcome'"=="education" local vlabelfile "Education"

if "`outcome'"=="consumption" local vtext_range "0(-0.05)-0.15"
if "`outcome'"=="consumption" local vtextA "-0.21"
if "`outcome'"=="consumption" local pos "28 35"
if "`outcome'"=="consumption" local vlabel "Consumption"
if "`outcome'"=="consumption" local vlabelfile "Consumption"

if "`outcome'"=="poor" local vtext_range "0(-0.10)-0.20"
if "`outcome'"=="poor" local vtextA "-0.26"
if "`outcome'"=="poor" local pos "28 35"
if "`outcome'"=="poor" local vlabel "Poor"
if "`outcome'"=="poor" local vlabelfile "Poor"

if "`outcome'"=="ubn" local vtext_range "0(-0.10)-0.40"
if "`outcome'"=="ubn" local vtextA "-0.46"
if "`outcome'"=="ubn" local pos "25 35"
if "`outcome'"=="ubn" local vlabel "# of Unsatisfied Needs"
if "`outcome'"=="ubn" local vlabelfile "UBN"

local vtextB=`vtextA'-0.14
local vtextC=`vtextA'-0.28
local vtextD=`vtextA'-0.36

*Rank
gen rank=_n

*Gen indicators and scatters
	local scoff=" "
	local scon=" "
	*Panel A
	local ind= `vtextA'-0.03
	foreach var in linear quadratic distance_border {
	   cap gen i_`var'=`ind'
	   local ind=`ind'-0.03
	   local scoff="`scoff' (scatter i_`var' rank, mcolor(gs10))" 
	   local scon="`scon' (scatter i_`var' rank if `var'==1, mcolor(black))" 
	}
	*Panel B
	local ind=`vtextB'-0.03
	foreach var in demographic geographic distance_rail {
	   cap gen i_`var'=`ind'
	   local ind=`ind'-0.03
	   local scoff="`scoff' (scatter i_`var' rank, mcolor(gs10))" 
	   local scon="`scon' (scatter i_`var' rank if `var'==1, mcolor(black))" 
	}
	*Panel C
	local ind=`vtextC'-0.03
	foreach var in MT_index {
	   cap gen i_`var'=`ind'
	   local ind=`ind'-0.03
	   local scoff="`scoff' (scatter i_`var' rank, mcolor(gs10))" 
	   local scon="`scon' (scatter i_`var' rank if `var'==1, mcolor(black))" 
	}	
	*Panel D
	local ind=`vtextD'-0.03
	foreach var in river top_10 top_5 any_mig head_mig hh_agri hh_no_agri head_agri head_no_agri {
	   cap gen i_`var'=`ind'
	   local ind=`ind'-0.03
	   local scoff="`scoff' (scatter i_`var' rank, mcolor(gs10))" 
	   local scon="`scon' (scatter i_`var' rank if `var'==1, mcolor(black))" 
	}	

*Plot
twoway (rbar u95 l95 rank, fcolor(gs12) lcolor(gs12) lwidth(none)) /// 95% CI clustered
   (rcap u95_conley l95_conley rank, fcolor(gs8) lcolor(gs8) lstyle(ci)) /// 95% CI Conley SE 
   (scatter beta rank if main==1, mcolor(blue) msymbol(S)) ///  main spec 
   (scatter beta rank  if main!=1, mcolor(black) msymbol(D)) ///  point estimates
   (function y = 0, lcolor(black) lpattern(dash) range(0.5 17.5)) ///  line at zero  
   `scoff' `scon' /// indicators for spec
   ,legend (order(3 "Main specification" 4 "Point estimate" 1 "95% CI (Clustered SE)" 2 "95% CI (Conley SE)") region(lcolor(white)) ///
	pos(12) ring(1) rows(2) size(small)) ///
   xtitle("") ytitle(`"`vlabel'"', size(small)) ///
   yscale(noline) xscale(noline) ylab(`"`vtext_range'"',noticks nogrid angle(horizontal) labsize(small)) xlab("", noticks)  ///
   graphregion (fcolor(white) lcolor(white)) plotregion(fcolor(white) lcolor(white))
   
*Now add stuff to the y axis  
gr_edit .yaxis1.add_ticks `vtextA' `"{bf:A. Specification f(location)}"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextA1=`vtextA'-0.03
gr_edit .yaxis1.add_ticks `vtextA1' `"A1. Linear polynomial in lat and lon"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextA2=`vtextA'-0.06
gr_edit .yaxis1.add_ticks `vtextA2' `"A2. Quadratic polynomial in lat and lon"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextA3=`vtextA'-0.09
gr_edit .yaxis1.add_ticks `vtextA3' `"A3. Distance to the UFCo border"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )

gr_edit .yaxis1.add_ticks `vtextB' `"{bf:B. Covariates}"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextB1=`vtextB'-0.03
gr_edit .yaxis1.add_ticks `vtextB1' `"B1. Demographic controls"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextB2=`vtextB'-0.06
gr_edit .yaxis1.add_ticks `vtextB2' `"B2. Geographic controls"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextB3=`vtextB'-0.09
gr_edit .yaxis1.add_ticks `vtextB3' `"B3. Distance to the railroad"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )

gr_edit .yaxis1.add_ticks `vtextC' `"{bf:C. Alternative index of UBN}"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextC1=`vtextC'-0.03
gr_edit .yaxis1.add_ticks `vtextC1' `"C1. Méndez & Trejos Index"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )

gr_edit .yaxis1.add_ticks `vtextD' `"{bf:D. Sample of households}"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextD1=`vtextD'-0.03
gr_edit .yaxis1.add_ticks `vtextD1' `"D1. River"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextD2=`vtextD'-0.06
gr_edit .yaxis1.add_ticks `vtextD2' `"D2. Omitting the Top 5% closest to the border"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextD3=`vtextD'-0.09
gr_edit .yaxis1.add_ticks `vtextD3' `"D3. Omitting the Top 10% closest to the border"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextD4=`vtextD'-0.12
gr_edit .yaxis1.add_ticks `vtextD4' `"D4. All members non-migrants"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextD5=`vtextD'-0.15
gr_edit .yaxis1.add_ticks `vtextD5' `"D5. Head of household non-migrant"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) ) 
local vtextD6=`vtextD'-0.18
gr_edit .yaxis1.add_ticks `vtextD6' `"D6. At least one member in agriculture"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextD7=`vtextD'-0.21
gr_edit .yaxis1.add_ticks `vtextD7' `"D7. No members in agriculture"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextD8=`vtextD'-0.24
gr_edit .yaxis1.add_ticks `vtextD8' `"D8. Head of household in agriculture"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextD9=`vtextD'-0.27
gr_edit .yaxis1.add_ticks `vtextD9' `"D9. Head of household not in agriculture"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) ) 

gr_edit yaxis1.title.DragBy `pos'

*Export figure
graph export "$dirout/Figure 5-`vlabelfile'.jpg", width(1600) height(1000) replace 
	
}