*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Figure D.7: Alternative Cutoffs for Conley Standard Errors and Main Results 
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the ado-file that implements the Conley Standard Errors (ols_spatial_HAC)
global dirado "..."

*Path to the final outputs (figures)
global dirout "..."

*Load the program that implements the Conley Standard Errors (ols_spatial_HAC)
run "$dirado/ols_spatial_HAC.ado" 

*Load dataset
use "$dirdata/Astua_Pirie_HH.dta", clear

*Initialize the group of variables:

*Geographic controls
local geographic elevation slope average_temp

*Demographic controls
local hh_controls adult infant children

*Census Fixed Effects
local year_fe y_2000 y_2011 y_1984 y_1973

*Latitude and longitude
local coordinates lat lon 

*Outcome variables
foreach outcome in housing health education consumption poor ubn {
	
display "`outcome'"	

*Generate the file to save the coefficients
tempname `outcome' 
postfile `outcome' cutoff beta se_conley df_r using "$dirout/`outcome'_Conley.dta", replace

*********************************************************************************************************************************************************************************************************************************************
* Figure D.7: Alternative Cutoffs for Conley Standard Errors and Main Results
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)

	*Store coefficient
	scalar coef = _b[UFCo]
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors at different cutoff
foreach distance_conley of numlist 2(1)10 {
	
display `distance_conley'	
	
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(`distance_conley') lag(0)

	*Store Conley Standard Errors
	scalar se_conley = _se[UFCo]
		
	*Store results 
	post `outcome' (`distance_conley') (`=coef') (`=se_conley') (`=df_r')
	
}

*********************************************************************************************************************************************************************************************************************************************
* Close file that saves coefficients and standard errors
*********************************************************************************************************************************************************************************************************************************************
postclose `outcome'
}

*********************************************************************************************************************************************************************************************************************************************
* Generate summary figure
*********************************************************************************************************************************************************************************************************************************************
foreach outcome in housing health education consumption poor ubn {
	
display "`outcome'"	
	
use "$dirout/`outcome'_Conley.dta",clear

gen u95_conley=beta+invt(df_r,0.975)*se_conley
gen l95_conley=beta-invt(df_r,0.975)*se_conley

if "`outcome'"=="housing" local vtext "Difference in the Probability of Unsatisfied Housing Need"
if "`outcome'"=="housing" local vtext_range "0(-0.05)-0.15"
if "`outcome'"=="health" local vtext "Difference in the Probability of Unsatisfied Health Need"
if "`outcome'"=="health" local vtext_range "0(-0.03)-0.06"
if "`outcome'"=="education" local vtext "Difference in the Probability of Unsatisfied Education Need"
if "`outcome'"=="education" local vtext_range "0(-0.05)-0.1"
if "`outcome'"=="consumption" local vtext "Difference in the Probability of Unsatisfied Consumption Need"
if "`outcome'"=="consumption" local vtext_range "0(-0.05)-0.1"
if "`outcome'"=="poor" local vtext "Difference in the Probability of Being Poor"
if "`outcome'"=="poor" local vtext_range "0(-0.05)-0.15"
if "`outcome'"=="ubn" local vtext "Difference in the # of Unsatisfied Needs" 
if "`outcome'"=="ubn" local vtext_range "0(-0.2)-0.4"

*Plot
twoway (rcap u95_conley l95_conley cutoff, fcolor(black) lcolor(black) lstyle(ci)) /// 95% CI Conley SE 
	(rcap u95_conley l95_conley cutoff if cutoff == 2, fcolor(blue) lcolor(blue) lstyle(ci)) /// 95% CI Conley SE main specification
   (scatter beta cutoff, mcolor(gs8) msymbol(S)) ///  main spec 
   (function y = 0, lcolor(black) lpattern(dash) range(2 10)) ///  line at zero  
   ,legend (order(3 "Coefficient main specification" 1 "95% CI Conley SE" 2 "95% CI Conley SE main specification") region(lcolor(white)) ///
	pos(12) ring(1) rows(2) size(small)) ///
   xtitle("Distance Cutoff for Conley SE", size(small)) ytitle(`"`vtext'"' "between UFCo and non-UFCo regions", size(small)) ///
   ylabel(`"`vtext_range'"') xlabel(2(1)10, labsize(small)) graphregion (fcolor(white))

graph export "$dirout/Figure D7-`outcome'_Conley.jpg", width(1600) height(1000) replace 
}