*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Figure 3: Average UFCo Effect Considering the Entire Concession's Border
*Figure 4: Dynamic UFCo Effect Considering the Entire Concession's Border

*This is the first code to obtain Figures 3 and 4. 
*Due to the sample size, it is preferable to estimate the Conley Standard Errors in MATLAB. Therefore, the code to generate Figure 3 and 4 is split.
*Part 1 estimates for each outcome a regression at a distance of 250 m up to 20 km from the UFCo border. The code also obtains the clustered standard errors, and the data to estimate the Conley Standard Errors in MATLAB.
*Part 2 estimates the Conley Standard Errors (in MATLAB).
*Part 3 imports and merges the outputs from MATLAB and Stata, and generates the plots.
*The instructions to generate Figure 3 and 4 are:
*1) Run "Figures 3 and 4 part 1.do" in Stata
*2) Run "Figures_3_and_4_part_2.m" in MATLAB
*3) Run "Figures 3 and 4 part 2.do" in Stata

*This code produces the files "housing_conley_input_", "health_conley_input_", 
*"education_conley_input_", "consumption_conley_input_", "ubn_conley_input_", 
*"poor_conley_input_", "housing_distance.dta", "housing_distance_dynamic.dta",
*"health_distance.dta", "health_distance_dynamic.dta",
*"education_distance.dta", "education_distance_dynamic.dta",
*"consumption_distance.dta", "consumption_distance_dynamic.dta",
*"poor_distance.dta", "poor_distance_dynamic.dta",
*"ubn_distance.dta", and "ubn_distance_dynamic.dta"
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata  "..."

*Path to the final outputs
global dirout "..."

*Load dataset
use "$dirdata/Census_HH.dta", replace

*Initialize the group of variables:

*Geographic controls
local geographic elevation slope average_temp

*Demographic controls
local hh_controls adult infant children

*Census Fixed Effects
local year_fe y_2000 y_2011 y_1984 y_1973

*Latitude and longitude
local coordinates lat lon 

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Outcome variables
foreach outcome in housing health education consumption poor ubn   {

****************************** Average UFCo Effect ******************************
*Estimates for different distance
tempname `outcome'_distance 
postfile `outcome'_distance distance coefficient ub lb using "$dirout/`outcome'_distance.dta", replace

forval x = 5(0.25)20 {
	display `x'
*Using Clustered Standard Errors at the Census Block Level
    reg `outcome' UFCo `covariates' if distance < `x', vce(cluster census_block)

	*Store results
	post `outcome'_distance (`x') (`=_b[UFCo]') (`=_b[UFCo]' + invttail(e(df_r),0.025)*`=_se[UFCo]') (`=_b[UFCo]' - invttail(e(df_r),0.025)*`=_se[UFCo]')
	
	gen df_r = e(N)-e(rank) //For Conley Standard Errors
	
*Generate file to estimate Conley Standard Errors in MATLAB
	outsheet `outcome' UFCo `covariates' census_block df_r if distance < `x' using "$dirout/`outcome'_conley_input_`x'.csv", comma nolabel replace	
	drop df_r
}
postclose `outcome'_distance

****************************** Dynamics Across Years ******************************
*Estimates for different distance
tempname `outcome'_distance_dynamic 
postfile `outcome'_distance_dynamic distance coef_1973 ub_1973 lb_1973 ///
coef_1984 ub_1984 lb_1984 coef_2000 ub_2000 lb_2000 coef_2011 ub_2011 lb_2011 using "$dirout/`outcome'_distance_dynamic.dta", replace

forval x = 5(0.25)20 {
	display `x'
    reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance < `x', vce(cluster census_block)
	post `outcome'_distance_dynamic (`x') (`=_b[UFCo_1973]') (`=_b[UFCo_1973]' + invttail(e(df_r),0.025)*`=_se[UFCo_1973]') (`=_b[UFCo_1973]' - invttail(e(df_r),0.025)*`=_se[UFCo_1973]') ///
	(`=_b[UFCo_1984]') (`=_b[UFCo_1984]' + invttail(e(df_r),0.025)*`=_se[UFCo_1984]') (`=_b[UFCo_1984]' - invttail(e(df_r),0.025)*`=_se[UFCo_1984]') ///
	(`=_b[UFCo_2000]') (`=_b[UFCo_2000]' + invttail(e(df_r),0.025)*`=_se[UFCo_2000]') (`=_b[UFCo_2000]' - invttail(e(df_r),0.025)*`=_se[UFCo_2000]') ///
	(`=_b[UFCo_2011]') (`=_b[UFCo_2011]' + invttail(e(df_r),0.025)*`=_se[UFCo_2011]') (`=_b[UFCo_2011]' - invttail(e(df_r),0.025)*`=_se[UFCo_2011]')
}
postclose `outcome'_distance_dynamic

}