*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Figure 3: Average UFCo Effect Considering the Entire Concession's Border
*Figure 4: Dynamic UFCo Effect Considering the Entire Concession's Border

*This is the third code to obtain Figures 3 and 4. 
*Due to the sample size, it is preferable to estimate the Conley Standard Errors in MATLAB. Therefore, the code to generate Figure 3 and 4 is split.
*Part 1 estimates for each outcome a regression at a distance of 250 m up to 20 km from the UFCo border. The code also obtains the clustered standard errors, and the data to estimate the Conley Standard Errors in MATLAB.
*Part 2 estimates the Conley Standard Errors (in MATLAB).
*Part 3 imports and merges the outputs from MATLAB and Stata, and generates the plots.
*The instructions to generate Figure 3 and 4 are:
*1) Run "Figures 3 and 4 part 1.do" in Stata
*2) Run "Figures_3_and_4_part_2.m" in MATLAB
*3) Run "Figures 3 and 4 part 2.do" in Stata

*This code uses the files "outcome_housing.csv", "outcome_health.csv",
*"outcome_education.csv", "outcome_consumption.csv", "outcome_poor.csv", 
*"outcome_ubn.csv" produced by "Figures_3_and_4_part_2.m"; and the files 
*"housing_distance.dta", "housing_distance_dynamic.dta",
*"health_distance.dta", "health_distance_dynamic.dta",
*"education_distance.dta", "education_distance_dynamic.dta",
*"consumption_distance.dta", "consumption_distance_dynamic.dta",
*"poor_distance.dta", "poor_distance_dynamic.dta",
*"ubn_distance.dta", and "ubn_distance_dynamic.dta", produced by "Figures 3 and 4 part 1.do"
version 16.1
clear all

set more off

*Path to the final outputs (figures)
global dirout "..."

*Import Conley Standard errors (obtained from MATLAB)
foreach outcome in housing health education consumption poor ubn   {

import delimited using "$dirout/outcome_`outcome'.csv", clear

rename v2 distance
rename v3 coeff
rename v4 Conley_se
rename v5 p_value
rename v6 df_r

gen outcome = "`outcome'" 

gen ub_Conley = coeff + invttail(df_r,0.025)*Conley_se
gen lb_Conley = coeff - invttail(df_r,0.025)*Conley_se

keep distance ub_Conley lb_Conley

*Save file
save "$dirout/outcome_`outcome'_Conley_SE.dta", replace

}

*Plots
foreach outcome in housing health education consumption poor ubn   {
use "$dirout/`outcome'_distance.dta", clear
merge 1:1 distance using "$dirout/`outcome'_distance_dynamic.dta"
drop _merge
merge 1:1 distance using "$dirout/outcome_`outcome'_Conley_SE.dta"

if "`outcome'"=="housing" local vtext "Difference in the Probability of Unsatisfied Housing"
if "`outcome'"=="housing" local vtext_range "-0.02(-0.02)-0.06"
if "`outcome'"=="housing" local vtext_range_dynamic "0(-0.10)-0.20"
if "`outcome'"=="housing" local vlabelfile "Housing"
if "`outcome'"=="health" local vtext "Difference in the Probability of Unsatisfied Health"
if "`outcome'"=="health" local vtext_range "-0.01(-0.01)-0.03"
if "`outcome'"=="health" local vtext_range_dynamic "0(-0.075)-0.15"
if "`outcome'"=="health" local vlabelfile "Health"
if "`outcome'"=="education" local vtext "Difference in the Probability of Unsatisfied Education"
if "`outcome'"=="education" local vtext_range "0.01 -0.01 -0.03"
if "`outcome'"=="education" local vtext_range_dynamic "0(-0.025)-0.05"
if "`outcome'"=="education" local vlabelfile "Education"
if "`outcome'"=="consumption" local vtext "Difference in the Probability of Unsatisfied Consumption"
if "`outcome'"=="consumption" local vtext_range "-0.01(-0.01)-0.03" 
if "`outcome'"=="consumption" local vtext_range_dynamic "0(-0.03)-0.06"
if "`outcome'"=="consumption" local vlabelfile "Consumption"
if "`outcome'"=="poor" local vtext "Difference in the Probability of Being Poor"
if "`outcome'"=="poor" local vtext_range "-0.01(-0.025)-0.06" 
if "`outcome'"=="poor" local vtext_range_dynamic "0(-0.05)-0.10" 
if "`outcome'"=="poor" local vlabelfile "Poor"
if "`outcome'"=="ubn" local vtext "Difference in the # of Unsatisfied Needs"
if "`outcome'"=="ubn" local vtext_range "-0.05(-0.05)-0.15"  
if "`outcome'"=="ubn" local vtext_range_dynamic "0(-0.25)-0.50"  
if "`outcome'"=="ubn" local vlabelfile "UBN"

if "`outcome'"=="housing" | "`outcome'"=="health" | "`outcome'"=="education" | "`outcome'"=="consumption" | "`outcome'"=="poor" {
twoway (rarea ub lb distance, bcolor(gs10) sort) ///
(line ub_Conley distance, lpattern(dot) lwidth(medthick) lcolor(black)) (line lb_Conley distance, lpattern(dot) lwidth(medthick) lcolor(black))  ///
(line coefficient distance, lwidth(thick) lcolor(black)) (lfit coefficient distance, lpattern(dash) lcolor(blue)), ///
graphregion(color(white)) ytitle(`"`vtext'"' "Need between UFCo and non-UFCo regions") ///
xtitle("Distance to the UFCo border (km)") xlabel(5(5)20) ylabel(`"`vtext_range'"') legend(off)
*Export figure
graph export "$dirout/Figure 3-`vlabelfile'.jpg", width(1600) height(1000) replace 

twoway (rarea ub_1973 lb_1973 distance, bcolor(gs14) sort) /// 
(rarea ub_1984 lb_1984 distance, bcolor(gs12) sort) ///
(rarea ub_2000 lb_2000 distance, bcolor(gs10) sort) ///
(rarea ub_2011 lb_2011 distance, bcolor(gs8) sort) ///
(line coef_1973 distance, lcolor(black)) ///
(line coef_1984 distance, lpattern(longdash) lcolor(navy)) (line coef_2000 distance, lpattern(shortdash_dot) lcolor(blue)) ///
(line coef_2011 distance, lpattern(longdash_dot) lcolor(eltblue)) ///
(function y = 0, lcolor(black) lpattern(solid) range(5 20)), ///  line at zero 
graphregion(color(white)) ytitle(`"`vtext'"' "between UFCo and non-UFCo regions") ///
xtitle("Distance to the UFCo Border (km)") xlabel(5 10 15 20) ylabel(`"`vtext_range_dynamic'"') legend(off)
*Export figure
graph export "$dirout/Figure 4-`vlabelfile'.jpg", width(1600) height(1000) replace 

}

if "`outcome'"=="ubn" {
twoway (rarea ub lb distance, bcolor(gs10) sort) ///
(line ub_Conley distance, lpattern(dot) lwidth(medthick) lcolor(black)) (line lb_Conley distance, lpattern(dot) lwidth(medthick) lcolor(black))  ///
(line coefficient distance, lwidth(thick) lcolor(black)) (lfit coefficient distance, lpattern(dash) lcolor(blue)), ///
graphregion(color(white)) ytitle(`"`vtext'"' "between UFCo and non-UFCo regions") ///
xtitle("Distance to the UFCo border (km)") xlabel(5(5)20) ylabel(`"`vtext_range'"') legend(off)
*Export figure
graph export "$dirout/Figure 3-`vlabelfile'.jpg", width(1600) height(1000) replace 

twoway (rarea ub_1973 lb_1973 distance, bcolor(gs14) sort) /// 
(rarea ub_1984 lb_1984 distance, bcolor(gs12) sort) ///
(rarea ub_2000 lb_2000 distance, bcolor(gs10) sort) ///
(rarea ub_2011 lb_2011 distance, bcolor(gs8) sort) ///
(line coef_1973 distance, lcolor(black)) ///
(line coef_1984 distance, lpattern(longdash) lcolor(navy)) (line coef_2000 distance, lpattern(shortdash_dot) lcolor(blue)) ///
(line coef_2011 distance, lpattern(longdash_dot) lcolor(eltblue)) ///
(function y = 0, lcolor(black) lpattern(solid) range(5 20)), ///  line at zero 
graphregion(color(white)) ytitle(`"`vtext'"' "between UFCo and non-UFCo regions") ///
xtitle("Distance to the UFCo Border (km)") xlabel(5(5)20) ylabel(`"`vtext_range_dynamic'"') legend(off)
*Export figure
graph export "$dirout/Figure 4-`vlabelfile'.jpg", width(1600) height(1000) replace 
}
}