*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Figures D.8 and D.9: Robustness checks, Main Specification, Dynamic UFCo Effect
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the ado-file that implements the Conley Standard Errors (ols_spatial_HAC)
global dirado "..."

*Path to the final outputs (figures)
global dirout "..."

*Load the program that implements the Conley Standard Errors (ols_spatial_HAC)
run "$dirado/ols_spatial_HAC.ado" 

*Load dataset
use "$dirdata/Astua_Pirie_HH.dta", clear

*Initialize the group of variables:

*Geographic controls
local geographic elevation slope average_temp

*Demographic controls
local hh_controls adult infant children

*Census Fixed Effects
local year_fe y_2000 y_2011 y_1984 y_1973

*Latitude and longitude
local coordinates lat lon 

*Outcome variables
foreach outcome in housing health education consumption poor ubn {
	
display "`outcome'"		

*Generate the file to save the coefficients
	tempname `outcome' 
	postfile `outcome' beta_1973 se_1973 beta_1984 se_1984 beta_2000 se_2000 beta_2011 se_2011 ///
	se_conley_1973 se_conley_1984 se_conley_2000 se_conley_2011 df_r ///
	main ///
	geographic demographic distance_border ///
	distance_rail linear quadratic ///
	top_10 top_5 ///
	any_mig head_mig ///
	using "$dirout/`outcome'_dynamic.dta", replace

*********************************************************************************************************************************************************************************************************************************************
* Figures D8 and D9 - Linear polynomial in latitude and longitude
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef_1973 = _b[UFCo_1973]
	scalar se_1973 = _se[UFCo_1973]
	scalar coef_1984 = _b[UFCo_1984]
	scalar se_1984 = _se[UFCo_1984]
	scalar coef_2000 = _b[UFCo_2000]
	scalar se_2000 = _se[UFCo_2000]
	scalar coef_2011 = _b[UFCo_2011]
	scalar se_2011 = _se[UFCo_2011]	
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley_1973 = _se[UFCo_1973]
	scalar se_conley_1984 = _se[UFCo_1984]
	scalar se_conley_2000 = _se[UFCo_2000]
	scalar se_conley_2011 = _se[UFCo_2011]	

	*Store coefficients 
	post `outcome' (`=coef_1973') (`=se_1973') (`=coef_1984') (`=se_1984') (`=coef_2000') (`=se_2000') (`=coef_2011') (`=se_2011') ///
	(`=se_conley_1973') (`=se_conley_1984') (`=se_conley_2000') (`=se_conley_2011') (`=df_r') ///
	(1) (1) (1) (.) (.) (1) (.) (.) (.) (.) (.)
	
*********************************************************************************************************************************************************************************************************************************************
* Figures D8 and D9 - Quadratic polynomial in latitude and longitude
*********************************************************************************************************************************************************************************************************************************************

*For quadratic polynomial, include latsqrt lonsqrt lat_lon in addition to lat and lon as covariates
*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe' latsqrt lonsqrt lat_lon 

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef_1973 = _b[UFCo_1973]
	scalar se_1973 = _se[UFCo_1973]
	scalar coef_1984 = _b[UFCo_1984]
	scalar se_1984 = _se[UFCo_1984]
	scalar coef_2000 = _b[UFCo_2000]
	scalar se_2000 = _se[UFCo_2000]
	scalar coef_2011 = _b[UFCo_2011]
	scalar se_2011 = _se[UFCo_2011]	
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley_1973 = _se[UFCo_1973]
	scalar se_conley_1984 = _se[UFCo_1984]
	scalar se_conley_2000 = _se[UFCo_2000]
	scalar se_conley_2011 = _se[UFCo_2011]	

	*Store coefficients 
	post `outcome' (`=coef_1973') (`=se_1973') (`=coef_1984') (`=se_1984') (`=coef_2000') (`=se_2000') (`=coef_2011') (`=se_2011') ///
	(`=se_conley_1973') (`=se_conley_1984') (`=se_conley_2000') (`=se_conley_2011') (`=df_r') ///
	(.) (1) (1) (.) (.) (.) (1) (.) (.) (.) (.)
	
*********************************************************************************************************************************************************************************************************************************************
* Figures D8 and D9 - Linear polynomial in latitude, longitude and distance to the border
*********************************************************************************************************************************************************************************************************************************************

*Include distance to the border as an additional covariate
*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe' distance

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, vce(cluster census_block)

	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef_1973 = _b[UFCo_1973]
	scalar se_1973 = _se[UFCo_1973]
	scalar coef_1984 = _b[UFCo_1984]
	scalar se_1984 = _se[UFCo_1984]
	scalar coef_2000 = _b[UFCo_2000]
	scalar se_2000 = _se[UFCo_2000]
	scalar coef_2011 = _b[UFCo_2011]
	scalar se_2011 = _se[UFCo_2011]	
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
		
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley_1973 = _se[UFCo_1973]
	scalar se_conley_1984 = _se[UFCo_1984]
	scalar se_conley_2000 = _se[UFCo_2000]
	scalar se_conley_2011 = _se[UFCo_2011]	

	*Store coefficients 
	post `outcome' (`=coef_1973') (`=se_1973') (`=coef_1984') (`=se_1984') (`=coef_2000') (`=se_2000') (`=coef_2011') (`=se_2011') ///
	(`=se_conley_1973') (`=se_conley_1984') (`=se_conley_2000') (`=se_conley_2011') (`=df_r') ///
	(.) (1) (1) (1) (.) (1) (.) (.) (.) (.) (.)
	
*********************************************************************************************************************************************************************************************************************************************
* Figures D8 and D9 - No demographic controls
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `geographic' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, vce(cluster census_block)

	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef_1973 = _b[UFCo_1973]
	scalar se_1973 = _se[UFCo_1973]
	scalar coef_1984 = _b[UFCo_1984]
	scalar se_1984 = _se[UFCo_1984]
	scalar coef_2000 = _b[UFCo_2000]
	scalar se_2000 = _se[UFCo_2000]
	scalar coef_2011 = _b[UFCo_2011]
	scalar se_2011 = _se[UFCo_2011]	
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley_1973 = _se[UFCo_1973]
	scalar se_conley_1984 = _se[UFCo_1984]
	scalar se_conley_2000 = _se[UFCo_2000]
	scalar se_conley_2011 = _se[UFCo_2011]	

	*Store coefficients 
	post `outcome' (`=coef_1973') (`=se_1973') (`=coef_1984') (`=se_1984') (`=coef_2000') (`=se_2000') (`=coef_2011') (`=se_2011') ///
	(`=se_conley_1973') (`=se_conley_1984') (`=se_conley_2000') (`=se_conley_2011') (`=df_r') ///
	(.) (1) (.) (.) (.) (1) (.) (.) (.) (.) (.)

*********************************************************************************************************************************************************************************************************************************************
* Figures D8 and D9 - No geographic controls
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef_1973 = _b[UFCo_1973]
	scalar se_1973 = _se[UFCo_1973]
	scalar coef_1984 = _b[UFCo_1984]
	scalar se_1984 = _se[UFCo_1984]
	scalar coef_2000 = _b[UFCo_2000]
	scalar se_2000 = _se[UFCo_2000]
	scalar coef_2011 = _b[UFCo_2011]
	scalar se_2011 = _se[UFCo_2011]	
	scalar df_r = e(df_r)	
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
		
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley_1973 = _se[UFCo_1973]
	scalar se_conley_1984 = _se[UFCo_1984]
	scalar se_conley_2000 = _se[UFCo_2000]
	scalar se_conley_2011 = _se[UFCo_2011]	
	
	*Store coefficients 
	post `outcome' (`=coef_1973') (`=se_1973') (`=coef_1984') (`=se_1984') (`=coef_2000') (`=se_2000') (`=coef_2011') (`=se_2011') ///
	(`=se_conley_1973') (`=se_conley_1984') (`=se_conley_2000') (`=se_conley_2011') (`=df_r') ///
	(.) (.) (1) (.) (.) (1) (.) (.) (.) (.) (.)

*********************************************************************************************************************************************************************************************************************************************
* Figures D8 and D9 - No demographic or geographic controls
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, vce(cluster census_block)

	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef_1973 = _b[UFCo_1973]
	scalar se_1973 = _se[UFCo_1973]
	scalar coef_1984 = _b[UFCo_1984]
	scalar se_1984 = _se[UFCo_1984]
	scalar coef_2000 = _b[UFCo_2000]
	scalar se_2000 = _se[UFCo_2000]
	scalar coef_2011 = _b[UFCo_2011]
	scalar se_2011 = _se[UFCo_2011]	
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley_1973 = _se[UFCo_1973]
	scalar se_conley_1984 = _se[UFCo_1984]
	scalar se_conley_2000 = _se[UFCo_2000]
	scalar se_conley_2011 = _se[UFCo_2011]	

	*Store coefficients 
	post `outcome' (`=coef_1973') (`=se_1973') (`=coef_1984') (`=se_1984') (`=coef_2000') (`=se_2000') (`=coef_2011') (`=se_2011') ///
	(`=se_conley_1973') (`=se_conley_1984') (`=se_conley_2000') (`=se_conley_2011') (`=df_r') ///
	(.) (.) (.) (.) (.) (1) (.) (.) (.) (.) (.)
	
*********************************************************************************************************************************************************************************************************************************************
* Figures D8 and D9 - Distance to Railroad
*********************************************************************************************************************************************************************************************************************************************

*Include distance to the railroad as an additional covariate
*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe' dist_railr

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef_1973 = _b[UFCo_1973]
	scalar se_1973 = _se[UFCo_1973]
	scalar coef_1984 = _b[UFCo_1984]
	scalar se_1984 = _se[UFCo_1984]
	scalar coef_2000 = _b[UFCo_2000]
	scalar se_2000 = _se[UFCo_2000]
	scalar coef_2011 = _b[UFCo_2011]
	scalar se_2011 = _se[UFCo_2011]	
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
		
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley_1973 = _se[UFCo_1973]
	scalar se_conley_1984 = _se[UFCo_1984]
	scalar se_conley_2000 = _se[UFCo_2000]
	scalar se_conley_2011 = _se[UFCo_2011]	

	*Store coefficients 
	post `outcome' (`=coef_1973') (`=se_1973') (`=coef_1984') (`=se_1984') (`=coef_2000') (`=se_2000') (`=coef_2011') (`=se_2011') ///
	(`=se_conley_1973') (`=se_conley_1984') (`=se_conley_2000') (`=se_conley_2011') (`=df_r') ///
	(.) (1) (1) (.) (1) (1) (.) (.) (.) (.) (.)
	
*********************************************************************************************************************************************************************************************************************************************
* Figures D8 and D9 - Drop top 5% and 10% observations closest to the border in each side
*********************************************************************************************************************************************************************************************************************************************
preserve

*Before estimating the percentiles, drop observations above threshold
drop if distance>5

*Generate percentile for UFCo region
xtile pctile = distance if UFCo==1, nq(100)

*Generate percentile for non-UFCo region
xtile pctile_non_UFCo = distance if UFCo==0, nq(100)

*Generate a unique percentile variable
replace pctile=pctile_non_UFCo if pctile==.

*Drop 5% closest observations to the border 
drop if pctile<=5

*Using Clustered Standard Errors at the Census Block Level
local covariates `coordinates' `geographic' `hh_controls' `year_fe'
	
	reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef_1973 = _b[UFCo_1973]
	scalar se_1973 = _se[UFCo_1973]
	scalar coef_1984 = _b[UFCo_1984]
	scalar se_1984 = _se[UFCo_1984]
	scalar coef_2000 = _b[UFCo_2000]
	scalar se_2000 = _se[UFCo_2000]
	scalar coef_2011 = _b[UFCo_2011]
	scalar se_2011 = _se[UFCo_2011]	
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
		
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley_1973 = _se[UFCo_1973]
	scalar se_conley_1984 = _se[UFCo_1984]
	scalar se_conley_2000 = _se[UFCo_2000]
	scalar se_conley_2011 = _se[UFCo_2011]	

	*Store coefficients 
	post `outcome' (`=coef_1973') (`=se_1973') (`=coef_1984') (`=se_1984') (`=coef_2000') (`=se_2000') (`=coef_2011') (`=se_2011') ///
	(`=se_conley_1973') (`=se_conley_1984') (`=se_conley_2000') (`=se_conley_2011') (`=df_r') ///
	(.) (1) (1) (.) (.) (1) (.) (.) (1) (.) (.)
		
*Drop 10% closest observations to the border 
drop if pctile<=10

*Using Clustered Standard Errors at the Census Block Level
local covariates `coordinates' `geographic' `hh_controls' `year_fe'
	
	reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef_1973 = _b[UFCo_1973]
	scalar se_1973 = _se[UFCo_1973]
	scalar coef_1984 = _b[UFCo_1984]
	scalar se_1984 = _se[UFCo_1984]
	scalar coef_2000 = _b[UFCo_2000]
	scalar se_2000 = _se[UFCo_2000]
	scalar coef_2011 = _b[UFCo_2011]
	scalar se_2011 = _se[UFCo_2011]	
	scalar df_r = e(df_r)
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
		
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley_1973 = _se[UFCo_1973]
	scalar se_conley_1984 = _se[UFCo_1984]
	scalar se_conley_2000 = _se[UFCo_2000]
	scalar se_conley_2011 = _se[UFCo_2011]	

	*Store coefficients 
	post `outcome' (`=coef_1973') (`=se_1973') (`=coef_1984') (`=se_1984') (`=coef_2000') (`=se_2000') (`=coef_2011') (`=se_2011') ///
	(`=se_conley_1973') (`=se_conley_1984') (`=se_conley_2000') (`=se_conley_2011') (`=df_r') ///
	(.) (1) (1) (.) (.) (1) (.) (.) (1) (.) (.)		

restore			

*********************************************************************************************************************************************************************************************************************************************
* Figures D8 and D9 - Any Migration
*********************************************************************************************************************************************************************************************************************************************
preserve

*Drop household if any member is migrant
drop if migration==1

*List of covariates 
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef_1973 = _b[UFCo_1973]
	scalar se_1973 = _se[UFCo_1973]
	scalar coef_1984 = _b[UFCo_1984]
	scalar se_1984 = _se[UFCo_1984]
	scalar coef_2000 = _b[UFCo_2000]
	scalar se_2000 = _se[UFCo_2000]
	scalar coef_2011 = _b[UFCo_2011]
	scalar se_2011 = _se[UFCo_2011]	
	scalar df_r = e(df_r)	
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
		
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley_1973 = _se[UFCo_1973]
	scalar se_conley_1984 = _se[UFCo_1984]
	scalar se_conley_2000 = _se[UFCo_2000]
	scalar se_conley_2011 = _se[UFCo_2011]	

	*Store coefficients 
	post `outcome' (`=coef_1973') (`=se_1973') (`=coef_1984') (`=se_1984') (`=coef_2000') (`=se_2000') (`=coef_2011') (`=se_2011') ///
	(`=se_conley_1973') (`=se_conley_1984') (`=se_conley_2000') (`=se_conley_2011') (`=df_r') ///
	(.) (1) (1) (.) (.) (1) (.) (.) (.) (1) (.)
	
restore

*********************************************************************************************************************************************************************************************************************************************
* Figures D8 and D9 - Migration Head
*********************************************************************************************************************************************************************************************************************************************
preserve

*Drop household if head of household is migrant
drop if migration_head==1

*List of covariates  
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, vce(cluster census_block)
	
	*Store coefficients for the summary figure (Clustered Standard Errors)
	scalar coef_1973 = _b[UFCo_1973]
	scalar se_1973 = _se[UFCo_1973]
	scalar coef_1984 = _b[UFCo_1984]
	scalar se_1984 = _se[UFCo_1984]
	scalar coef_2000 = _b[UFCo_2000]
	scalar se_2000 = _se[UFCo_2000]
	scalar coef_2011 = _b[UFCo_2011]
	scalar se_2011 = _se[UFCo_2011]	
	scalar df_r = e(df_r)	
	
	*Adjusted R2
	display e(r2_a) " Adjusted R2"
	
	*Mean
	sum `outcome' if distance<5 & year==1973
	sum `outcome' if distance<5 & year==1984
	sum `outcome' if distance<5 & year==2000
	sum `outcome' if distance<5 & year==2011	
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo_1973 UFCo_1984 UFCo_2000 UFCo_2011 `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
		
	*Store coefficients for the summary figure (Conley Standard Errors)
	scalar se_conley_1973 = _se[UFCo_1973]
	scalar se_conley_1984 = _se[UFCo_1984]
	scalar se_conley_2000 = _se[UFCo_2000]
	scalar se_conley_2011 = _se[UFCo_2011]	

	*Store coefficients 
	post `outcome' (`=coef_1973') (`=se_1973') (`=coef_1984') (`=se_1984') (`=coef_2000') (`=se_2000') (`=coef_2011') (`=se_2011') ///
	(`=se_conley_1973') (`=se_conley_1984') (`=se_conley_2000') (`=se_conley_2011') (`=df_r') ///
	(.) (1) (1) (.) (.) (1) (.) (.) (.) (.) (1)

restore

*********************************************************************************************************************************************************************************************************************************************
* Close file that saves coefficients and standard errors
*********************************************************************************************************************************************************************************************************************************************
postclose `outcome'
}	

*********************************************************************************************************************************************************************************************************************************************
* Generate summary figure
*********************************************************************************************************************************************************************************************************************************************
*Based on the specification curve code ("speccurve") by Hans H. Sievertsen. Available at: https://github.com/hhsievertsen/speccurve
foreach outcome in housing health education consumption poor ubn   {
display "`outcome'"
use "$dirout/`outcome'_dynamic.dta",clear

*Specification id
gen spec_id = _n

*Confidence intervals
gen u95_1973=beta_1973+invt(df_r,0.975)*se_1973
gen l95_1973=beta_1973-invt(df_r,0.975)*se_1973

gen u95_1984=beta_1984+invt(df_r,0.975)*se_1984
gen l95_1984=beta_1984-invt(df_r,0.975)*se_1984

gen u95_2000=beta_2000+invt(df_r,0.975)*se_2000
gen l95_2000=beta_2000-invt(df_r,0.975)*se_2000

gen u95_2011=beta_2011+invt(df_r,0.975)*se_2011
gen l95_2011=beta_2011-invt(df_r,0.975)*se_2011

gen u95_conley_1973=beta_1973+invt(df_r,0.975)*se_conley_1973
gen l95_conley_1973=beta_1973-invt(df_r,0.975)*se_conley_1973

gen u95_conley_1984=beta_1984+invt(df_r,0.975)*se_conley_1984
gen l95_conley_1984=beta_1984-invt(df_r,0.975)*se_conley_1984

gen u95_conley_2000=beta_2000+invt(df_r,0.975)*se_conley_2000
gen l95_conley_2000=beta_2000-invt(df_r,0.975)*se_conley_2000

gen u95_conley_2011=beta_2011+invt(df_r,0.975)*se_conley_2011
gen l95_conley_2011=beta_2011-invt(df_r,0.975)*se_conley_2011

if "`outcome'"=="housing" local vtext_range "0(-0.20)-0.40"
if "`outcome'"=="housing" local vtextA "-0.46"
if "`outcome'"=="housing" local pos "20 35"
if "`outcome'"=="housing" local vlabel "Housing"
if "`outcome'"=="housing" local vlabelfile "Housing"

if "`outcome'"=="health" local vtext_range "0(-0.25)-0.50"
if "`outcome'"=="health" local vtextA "-0.56"
if "`outcome'"=="health" local pos "15 33"
if "`outcome'"=="health" local vlabel "Health"
if "`outcome'"=="health" local vlabelfile "Health"

if "`outcome'"=="education" local vtext_range "0(-0.10)-0.20"
if "`outcome'"=="education" local vtextA "-0.26"
if "`outcome'"=="education" local pos "23 35"
if "`outcome'"=="education" local vlabel "Education"
if "`outcome'"=="education" local vlabelfile "Education"

if "`outcome'"=="consumption" local vtext_range "0(-0.10)-0.20"
if "`outcome'"=="consumption" local vtextA "-0.26"
if "`outcome'"=="consumption" local pos "20 35"
if "`outcome'"=="consumption" local vlabel "Consumption"
if "`outcome'"=="consumption" local vlabelfile "Consumption"

if "`outcome'"=="poor" local vtext_range "0(-0.2)-0.40"
if "`outcome'"=="poor" local vtextA "-0.46"
if "`outcome'"=="poor" local pos "20 35"
if "`outcome'"=="poor" local vlabel "Poor"
if "`outcome'"=="poor" local vlabelfile "Poor"

if "`outcome'"=="ubn" local vtext_range "0(-0.60)-1.2"
if "`outcome'"=="ubn" local vtextA "-1.26"
if "`outcome'"=="ubn" local pos "10 35"
if "`outcome'"=="ubn" local vlabel "# of Unsatisfied Needs"
if "`outcome'"=="ubn" local vlabelfile "UBN"

if "`outcome'"!="ubn" {
local vtextB=`vtextA'-0.14
local vtextC=`vtextA'-0.28
}

if "`outcome'"=="ubn" {
local vtextB=`vtextA'-0.25
local vtextC=`vtextA'-0.50
}

*Rank
gen rank=_n

*Gen indicators and scatters
	local scoff=" "
	local scon=" "
if "`outcome'"!="ubn" {
	*Panel A
	local ind= `vtextA'-0.03
	foreach var in linear quadratic distance_border {
	   cap gen i_`var'=`ind'
	   local ind=`ind'-0.03
	   local scoff="`scoff' (scatter i_`var' rank, mcolor(gs10))" 
	   local scon="`scon' (scatter i_`var' rank if `var'==1, mcolor(black))" 
	}
	*Panel B
	local ind=`vtextB'-0.03
	foreach var in demographic geographic distance_rail {
	   cap gen i_`var'=`ind'
	   local ind=`ind'-0.03
	   local scoff="`scoff' (scatter i_`var' rank, mcolor(gs10))" 
	   local scon="`scon' (scatter i_`var' rank if `var'==1, mcolor(black))" 
	}
	
	*Panel C
	local ind=`vtextC'-0.03
	foreach var in top_10 top_5 any_mig head_mig {
	   cap gen i_`var'=`ind'
	   local ind=`ind'-0.03
	   local scoff="`scoff' (scatter i_`var' rank, mcolor(gs10))" 
	   local scon="`scon' (scatter i_`var' rank if `var'==1, mcolor(black))" 
	}
}	
if "`outcome'"=="ubn" {
	*Panel A
	local ind= `vtextA'-0.06
	foreach var in linear quadratic distance_border {
	   cap gen i_`var'=`ind'
	   local ind=`ind'-0.06
	   local scoff="`scoff' (scatter i_`var' rank, mcolor(gs10))" 
	   local scon="`scon' (scatter i_`var' rank if `var'==1, mcolor(black))" 
	}
	*Panel B
	local ind=`vtextB'-0.06
	foreach var in demographic geographic distance_rail {
	   cap gen i_`var'=`ind'
	   local ind=`ind'-0.06
	   local scoff="`scoff' (scatter i_`var' rank, mcolor(gs10))" 
	   local scon="`scon' (scatter i_`var' rank if `var'==1, mcolor(black))" 
	}
	
	*Panel C
	local ind=`vtextC'-0.06
	foreach var in top_10 top_5 any_mig head_mig {
	   cap gen i_`var'=`ind'
	   local ind=`ind'-0.06
	   local scoff="`scoff' (scatter i_`var' rank, mcolor(gs10))" 
	   local scon="`scon' (scatter i_`var' rank if `var'==1, mcolor(black))" 
	}
}

*Plot
twoway (rbar u95_1973 l95_1973 rank, fcolor(gs12) lcolor(gs12) lwidth(none)) /// 95% CI clustered 1973
    (rbar u95_2011 l95_2011 rank, fcolor(gs12) lcolor(gs12) lwidth(none)) /// 95% CI clustered 2011
    (rcap u95_conley_1973 l95_conley_1973 rank, fcolor(gs8) lcolor(gs8) lstyle(ci)) /// 95% CI Conley SE 1973
    (rcap u95_conley_2011 l95_conley_2011 rank, fcolor(gs8) lcolor(gs8) lstyle(ci)) /// 95% CI Conley SE 2011
    (scatter beta_1973 rank if main==1, mcolor(blue) msymbol(S)) ///  main spec 1973
	(scatter beta_2011 rank if main==1, mcolor(blue) msymbol(D)) ///  main spec 2011   
   (scatter beta_1973 rank  if main!=1, mcolor(black) msymbol(s)) ///  point estimates 1973
   (scatter beta_2011 rank  if main!=1, mcolor(black) msymbol(d)) ///  point estimates 2011   
   `scoff' `scon' /// indicators for spec
   (function y = 0, lcolor(black) lpattern(dash) range(0.5 11.5)) ///  line at zero  
   ,legend (order(5 "Main specification 1973" 6 "Main specification 2011" 7 "Point estimate 1973" 8 "Point estimate 2011" ///
   1 "95% CI (Clustered SE)" 3 "95% CI (Conley SE)") region(lcolor(white)) ///
	pos(12) ring(1) rows(3) size(small)) ///
   xtitle("") ytitle(`"`vlabel'"', size(small)) ///
   yscale(noline) xscale(noline) ylab(`"`vtext_range'"',noticks nogrid angle(horizontal) labsize(small)) xlab("", noticks)  ///
   graphregion (fcolor(white) lcolor(white)) plotregion(fcolor(white) lcolor(white))
   
*Now add stuff to the y axis 
if "`outcome'"!="ubn" { 
gr_edit .yaxis1.add_ticks `vtextA' `"{bf:A. Specification f(location)}"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextA1=`vtextA'-0.03
gr_edit .yaxis1.add_ticks `vtextA1' `"A1. Linear polynomial in lat and lon"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextA2=`vtextA'-0.06
gr_edit .yaxis1.add_ticks `vtextA2' `"A2. Quadratic polynomial in lat and lon"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextA3=`vtextA'-0.09
gr_edit .yaxis1.add_ticks `vtextA3' `"A3. Distance to the UFCo border"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )

gr_edit .yaxis1.add_ticks `vtextB' `"{bf:B. Covariates}"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextB1=`vtextB'-0.03
gr_edit .yaxis1.add_ticks `vtextB1' `"B1. Demographic controls"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextB2=`vtextB'-0.06
gr_edit .yaxis1.add_ticks `vtextB2' `"B2. Geographic controls"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextB3=`vtextB'-0.09
gr_edit .yaxis1.add_ticks `vtextB3' `"B3. Distance to the railroad"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )

gr_edit .yaxis1.add_ticks `vtextC' `"{bf:C. Sample of households}"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextC1=`vtextC'-0.03
gr_edit .yaxis1.add_ticks `vtextC1' `"C1. Omitting the Top 5% closest to the border"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextC2=`vtextC'-0.06
gr_edit .yaxis1.add_ticks `vtextC2' `"C2. Omitting the Top 10% closest to the border"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextC3=`vtextC'-0.09
gr_edit .yaxis1.add_ticks `vtextC3' `"C3. All members non-migrants"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextC4=`vtextC'-0.12
gr_edit .yaxis1.add_ticks `vtextC4' `"C4. Head of household non-migrant"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) ) 
local vtextC5=`vtextC'-0.15
}
if "`outcome'"=="ubn" { 
gr_edit .yaxis1.add_ticks `vtextA' `"{bf:A. Specification f(location)}"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextA1=`vtextA'-0.06
gr_edit .yaxis1.add_ticks `vtextA1' `"A1. Linear polynomial in lat and lon"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextA2=`vtextA'-0.12
gr_edit .yaxis1.add_ticks `vtextA2' `"A2. Quadratic polynomial in lat and lon"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextA3=`vtextA'-0.18
gr_edit .yaxis1.add_ticks `vtextA3' `"A3. Distance to the UFCo border"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )

gr_edit .yaxis1.add_ticks `vtextB' `"{bf:B. Covariates}"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextB1=`vtextB'-0.06
gr_edit .yaxis1.add_ticks `vtextB1' `"B1. Demographic controls"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextB2=`vtextB'-0.12
gr_edit .yaxis1.add_ticks `vtextB2' `"B2. Geographic controls"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextB3=`vtextB'-0.18
gr_edit .yaxis1.add_ticks `vtextB3' `"B3. Distance to the railroad"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )

gr_edit .yaxis1.add_ticks `vtextC' `"{bf:C. Sample of households}"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextC1=`vtextC'-0.06
gr_edit .yaxis1.add_ticks `vtextC1' `"C1. Omitting the Top 5% closest to the border"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextC2=`vtextC'-0.12
gr_edit .yaxis1.add_ticks `vtextC2' `"C2. Omitting the Top 10% closest to the border"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextC3=`vtextC'-0.18
gr_edit .yaxis1.add_ticks `vtextC3' `"C3. All members non-migrants"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) )
local vtextC4=`vtextC'-0.24
gr_edit .yaxis1.add_ticks `vtextC4' `"C4. Head of household non-migrant"', custom tickset(major) editstyle(tickstyle(textstyle(size(vsmall))) ) 
local vtextC5=`vtextC'-0.30
}

gr_edit yaxis1.title.DragBy `pos'

*Difference in the Probability of an Unsatisfied Need between UFCo and non-UFCo Households
if "`outcome'"=="poor" | "`outcome'"=="ubn" { 
graph export "$dirout/Figure D8-`vlabelfile'.jpg", width(1600) height(1000) replace 
}
if "`outcome'"=="housing" | "`outcome'"=="health" | "`outcome'"=="education" | "`outcome'"=="consumption" { 
graph export "$dirout/Figure D9-`vlabelfile'.jpg", width(1600) height(1000) replace 
}

}